@@ -1126,16 +1126,37 @@ SEXP group_col_med_h(SEXP x,SEXP gr,const int length_unique){
 
 template<class Ret,class T>
 Ret Quantile(T x,colvec& probs){
-    Ret f(probs.n_elem);
-    sort(x.begin(),x.end());
+  Ret f(probs.n_elem);
+  
+  if(probs.size() > std::log2(x.size())){ // k > log2(n) tote allazo algorithmo
+    const int mxelem = (x.n_elem-1)*(*max_element(probs.begin(),probs.end()))+1;
+    std::nth_element(x.begin(),x.begin()+mxelem,x.end());
+    std::sort(x.begin(),x.end());
     for(unsigned int i=0;i<probs.n_elem;++i){
-        double h=(x.n_elem-1)*probs[i]+1;
-        int hf=h;
-        auto a=x[hf-1];
-        auto b=x[hf];
-        f[i] = a + (h-hf) * ( b - a );
+      double h=(x.n_elem-1)*probs[i]+1;
+      int hf=h;
+      auto a=x[hf-1];
+      auto b=x[hf];
+      f[i] = a + (h-hf) * ( b - a );
     }
-    return f;
+    
+  }else{
+    for(unsigned int i=0;i<probs.n_elem;++i){
+      double h=(x.n_elem-1)*probs[i]+1;
+      int hf=h;
+      double a,b;
+      if(probs[i] > 0.5){
+        a = nth_simple<T>(x, hf-1,false);
+        b = *min_element(x.begin()+hf,x.end());
+      }else{
+        b = nth_simple<T>(x, hf,false);
+        a = *max_element(x.begin(),x.begin()+hf);
+      }
+      f[i] = a + (h-hf) * ( b - a );
+    }
+  }
+  
+  return f;
 }
 
 template<class T>
